% demoEnvMapGeneration.m

%% Setup (edit)

% location of the environment map conversion routines
envMapConversionPath = '../../envMapping/conversion';

% location of the sky model code
skyModelPath = '../skyModeling/skyModel';

% location of the 'parseArgs' package
parseArgsPath = '../../../3rd_party/parseArgs';

% pixel height of the resulting environment map in lat-long format,
% width=2*height
envMapHeight = 500;

% Should run automatically from here.

% add paths
addpath(envMapConversionPath);
addpath(skyModelPath);
addpath(parseArgsPath);


%% Load image and associated information
img = im2double(imread(fullfile('data', 'img.jpg')));
sceneMask = logical(imread(fullfile('data', 'sceneMask.jpg')));
imgData = load(fullfile('data', 'img.mat'));

%% Load sun model
sunModelData = load(fullfile('data', 'sunModelCentered.mat'));
airMassModelData = load(fullfile('data', 'airMassModel.mat'));

%% Synthesize sky env map
tic;
fprintf('Generating the sky...\n');
envMapSky = envmapSequenceSky2EnvMap(img, imgData.skyTurbidity, imgData.skyScaleFactors, ...
    0, imgData.sunZenith, -imgData.sunRelativeAzimuth, 'EnvMapHeight', envMapHeight);

%% Synthesize sun env map
fprintf('Generating the sun...\n');
angularEnvMap = envmapLatLong2Angular(envMapSky, envMapHeight*2);
envMapSun = addSunToEnvMap(angularEnvMap, imgData.sunZenith, imgData.sunRelativeAzimuth, ...
    sunModelData.meanData, sunModelData.dSun, airMassModelData.sunParams, 0, 'DoSunLight', 0);
envMapSun = envmapAngular2LatLong(envMapSun, envMapHeight);

%% Synthesize ground env map
fprintf('Generating the ground...\n');
[envMapGround, envMapGroundMask] = addGroundToEnvMap(img, imdilate(~sceneMask, strel('disk', 2)), ...
    sceneMask, imgData.horizonLine, imgData.focalLength, imgData.camZenith, envMapHeight);

envMapGroundBottom = cat(1, zeros(size(envMapGround,1)/2+1, size(envMapGround,2), 3), envMapGround(size(envMapGround,1)/2+2:end, :, :));
envMapGroundBottomMask = cat(1, zeros(size(envMapGround,1)/2+1, size(envMapGround,2)), envMapGroundMask(size(envMapGround,1)/2+2:end, :));
    
%% Combine environment maps
fprintf('Combining...\n');
envMap = envMapSun.*(1-repmat(envMapGroundMask, [1 1 3])) + envMapGround.*repmat(envMapGroundMask, [1 1 3]);

%% Visualize the result
fprintf('done in %.2fs!\n', toc);
% show in RGB
figure(1); 
imshow(envMap); title('Environment map in lat-long format');

% visualize high dynamic range
figure(2);
imagesc(log(envMap(:,:,1))); axis off image; colorbar;
title('Log of the R-channel to show high dynamic range'); 