%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function m = opticalMass(theta_s)
%  Computes optical mass (thickness of atmosphere) for a sun zenith angle.  
% 
% Input parameters: 
%  - theta_s: sun zenith angle
% 
% Output parameters: 
%  - m: optical mass
%  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function m = opticalMass(theta_s)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright 2006-2011 Jean-Francois Lalonde
% Carnegie Mellon University
% Do not distribute
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% from Preetham's paper
%         m = 1./(cos(theta_s) + 0.15.*(93.885-theta_s.*180./pi).^-1.253);

% from Kasten and Young (1989)
m = 1./(cos(theta_s) + 0.50572.*(96.07995-theta_s.*180/pi).^(-1.6364));
